---
title: <span class="badge object-type-scalar"></span> SquareFeet
---
# <span class="badge object-type-scalar"></span> SquareFeet

Area: Square Feet (ft²)

## Definition

```python
# Area: Square Feet (ft²)
SquareFeet: typing.Literal["areaF2"] = "areaF2"
```
